==> jc-1.4.0.tar.gz: gnu/xml/dom/ImplementationList.h <==
// public class gnu.xml.dom.ImplementationList

// class file dependencies
// @dep_class 6f9d3c9ae4ffef4a gnu_xml_dom_ImplementationList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_ImplementationList_H_
#define _JC_gnu_xml_dom_ImplementationList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_DOMImplementation$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ImplementationList$sub_refs	_jc_gnu_xml_dom_ImplementationList$sub_refs;
typedef struct _jc_gnu_xml_dom_ImplementationList$sub_nonrefs	_jc_gnu_xml_dom_ImplementationList$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationList$refs	_jc_gnu_xml_dom_ImplementationList$refs;
typedef struct _jc_gnu_xml_dom_ImplementationList$nonrefs	_jc_gnu_xml_dom_ImplementationList$nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationList$object	_jc_gnu_xml_dom_ImplementationList$object;

typedef const struct _jc_gnu_xml_dom_ImplementationList$vmethods	_jc_gnu_xml_dom_ImplementationList$vmethods;
typedef const struct _jc_gnu_xml_dom_ImplementationList$vtable	_jc_gnu_xml_dom_ImplementationList$vtable;
typedef const struct _jc_gnu_xml_dom_ImplementationList$vtype	_jc_gnu_xml_dom_ImplementationList$vtype;

// Constructors
extern void _jc_gnu_xml_dom_ImplementationList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_gnu_xml_dom_ImplementationList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *);
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationList$method$item$ad3f93e30f338189(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_ImplementationList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_dom_ImplementationList$method_info$item$ad3f93e30f338189;

// Virtual methods structure
struct _jc_gnu_xml_dom_ImplementationList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *);
	struct _jc_object	*(*item$ad3f93e30f338189)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_dom_ImplementationList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_ImplementationList$vmethods	gnu_xml_dom_ImplementationList;
};

// Vtype
struct _jc_gnu_xml_dom_ImplementationList$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ImplementationList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationList$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationList$refs {
    _jc_gnu_xml_dom_ImplementationList$sub_refs	gnu_xml_dom_ImplementationList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_ImplementationList$sub_nonrefs	gnu_xml_dom_ImplementationList;
};

// Object instance structure
struct _jc_gnu_xml_dom_ImplementationList$object {
	_jc_gnu_xml_dom_ImplementationList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ImplementationList$vtype	*vtype;
	_jc_gnu_xml_dom_ImplementationList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ImplementationList$vtype _jc_gnu_xml_dom_ImplementationList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ImplementationList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ImplementationList$class_object;

#endif	/* _JC_gnu_xml_dom_ImplementationList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/ImplementationList.h <==
// public class gnu.xml.dom.ImplementationList

// class file dependencies
// @dep_class 6f9d3c9ae4ffef4a gnu_xml_dom_ImplementationList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_ImplementationList_H_
#define _JC_gnu_xml_dom_ImplementationList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_DOMImplementation$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ImplementationList$sub_refs	_jc_gnu_xml_dom_ImplementationList$sub_refs;
typedef struct _jc_gnu_xml_dom_ImplementationList$sub_nonrefs	_jc_gnu_xml_dom_ImplementationList$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationList$refs	_jc_gnu_xml_dom_ImplementationList$refs;
typedef struct _jc_gnu_xml_dom_ImplementationList$nonrefs	_jc_gnu_xml_dom_ImplementationList$nonrefs;
typedef struct _jc_gnu_xml_dom_ImplementationList$object	_jc_gnu_xml_dom_ImplementationList$object;

typedef const struct _jc_gnu_xml_dom_ImplementationList$vmethods	_jc_gnu_xml_dom_ImplementationList$vmethods;
typedef const struct _jc_gnu_xml_dom_ImplementationList$vtable	_jc_gnu_xml_dom_ImplementationList$vtable;
typedef const struct _jc_gnu_xml_dom_ImplementationList$vtype	_jc_gnu_xml_dom_ImplementationList$vtype;

// Constructors
extern void _jc_gnu_xml_dom_ImplementationList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_dom_ImplementationList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_ImplementationList$method$item$ad3f93e30f338189(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_ImplementationList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_dom_ImplementationList$method_info$item$ad3f93e30f338189;

// Virtual methods structure
struct _jc_gnu_xml_dom_ImplementationList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$ad3f93e30f338189)(_jc_env *, struct _jc_gnu_xml_dom_ImplementationList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_ImplementationList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_ImplementationList$vmethods	gnu_xml_dom_ImplementationList;
};

// Vtype
struct _jc_gnu_xml_dom_ImplementationList$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ImplementationList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationList$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationList$refs {
    _jc_gnu_xml_dom_ImplementationList$sub_refs	gnu_xml_dom_ImplementationList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ImplementationList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ImplementationList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_ImplementationList$sub_nonrefs	gnu_xml_dom_ImplementationList;
};

// Object instance structure
struct _jc_gnu_xml_dom_ImplementationList$object {
	_jc_gnu_xml_dom_ImplementationList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ImplementationList$vtype	*vtype;
	_jc_gnu_xml_dom_ImplementationList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ImplementationList$vtype _jc_gnu_xml_dom_ImplementationList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ImplementationList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ImplementationList$class_object;

#endif	/* _JC_gnu_xml_dom_ImplementationList_H_ */
